==> newsx_1.4.orig.tar.gz: newsx-1.4/src/news.h <==
/*  VER 048  TAB P   $Id: news.h,v 1.15 1999/04/19 04:20:08 src Exp $
 *
 *  news system filename "common knowlegde"
 *
 *  copyright 1996, 1997, 1998 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  NOTE: shouldn't normally need to change these
 *
 *  $Log: news.h,v $
 *  Revision 1.15  1999/04/19 04:20:08  src
 *  Profile for specific spool
 *
 *  Revision 1.14  1999/04/19 03:32:39  src
 *  Standard profile in $PATHETC/newsx.conf
 *
 *  Revision 1.13  1999/04/06 03:43:40  src
 *  INN hostname for incoming spool
 *
 *  Revision 1.12  1999/04/03 12:13:44  src
 *  Fixed error in mktemp usage, reported by Stefan Huelswitt <huels@iname.com>
 *
 *  Revision 1.11  1999/03/31 05:53:46  src
 *  Seperated MAXHEADERSIZE from NNTP_STRLEN
 *
 *  Revision 1.10  1999/03/24 10:03:48  src
 *  Document
 *
 *  Revision 1.9  1999/03/24 09:56:19  src
 *  Made name of lockfile compatible with INN
 *
 *  Revision 1.8  1999/03/24 03:52:59  src
 *  Implemented "newsx" as magic exclude pattern
 *
 *  Revision 1.7  1998/09/11 16:37:44  src
 *  Lockfile for logfile of posted articles and for posted article folder.
 *
 *  Revision 1.6  1998/09/09 07:32:12  src
 *  Version 1.1
 *
 *  Revision 1.5  1998/07/12 09:39:29  src
 *  newsx version 1.0
 */

/*
 *  length of a news header line
 *  not to be confused with NNTP_STRLEN
 */
#define MAXHEADERSIZE  5120

/* 
 *  lock between newsxes accessing same host
 *  name compatible with INN innstat
 */
#define LOCK_PREFIX     "LOCK.newsx."

/* 
 *  lock between newsxes accessing same log file
 */
#define LOCK_SUFFIX     ".LOCKnewsx"

/* 
 *  outgoing  
 */
#define C_TOGO          "togo"          /* C News */
#define C_LOCK          "LOCKb"         /* C News */
#define I_LOCK          "LOCK."         /* INN */

#define C_SYS_FILE      "sys"           /* C News */

/* 
 *  incoming
 */
#define _IN_TMP         "/.tmp."        /* temp prefix, invisible to newsrun */
#define _C_SPOOL        "%ld.%d.%d.t"   /* C incoming news name, uncompressed */
#define _INN_SPOOL      "XXXXXX"        /* INN incoming news pattern */

/*
 *  control
 */
#define INN_CTL         "ctlinnd"       /* INN */
#define INN_CTL_FLUSH   "flush"         /* INN ctlinnd */

/*
 *  "magic" newsx path tag
 */
#define NEWSX_PATH      "newsx"

/*
 *  newsx standard configuration file
 */
#define NEWSX_CONF      "newsx.conf"

/* 
 *  general
 */
#define _RETRY          ".retry"
#define _OLD            ".old"
#define _TMP            ".tmp"
#define _TOGO           ".togo"
#define _CONF           ".conf"

==> newsx-1.6.tar.gz: newsx-1.6/src/news.h <==
/*  VER 051  TAB P   $Id: news.h,v 1.15.2.2 2003/01/21 20:19:45 egil Exp $
 *
 *  news system filename "common knowlegde"
 *
 *  copyright 1996, 1997, 1998 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  NOTE: shouldn't normally need to change these
 *
 *  $Log: news.h,v $
 *  Revision 1.15.2.2  2003/01/21 20:19:45  egil
 *  mktemp() replaced by newstemp()
 *
 *  Revision 1.15.2.1  2003/01/21 09:47:25  egil
 *  Renamed MAXHEADERSIZE to MAX_HEADER_SIZE due to name collision
 *
 *  Revision 1.15  1999/04/19 04:20:08  src
 *  Profile for specific spool
 *
 *  Revision 1.14  1999/04/19 03:32:39  src
 *  Standard profile in $PATHETC/newsx.conf
 *
 *  Revision 1.13  1999/04/06 03:43:40  src
 *  INN hostname for incoming spool
 *
 *  Revision 1.12  1999/04/03 12:13:44  src
 *  Fixed error in mktemp usage, reported by Stefan Huelswitt <huels@iname.com>
 *
 *  Revision 1.11  1999/03/31 05:53:46  src
 *  Seperated MAXHEADERSIZE from NNTP_STRLEN
 *
 *  Revision 1.10  1999/03/24 10:03:48  src
 *  Document
 *
 *  Revision 1.9  1999/03/24 09:56:19  src
 *  Made name of lockfile compatible with INN
 *
 *  Revision 1.8  1999/03/24 03:52:59  src
 *  Implemented "newsx" as magic exclude pattern
 *
 *  Revision 1.7  1998/09/11 16:37:44  src
 *  Lockfile for logfile of posted articles and for posted article folder.
 *
 *  Revision 1.6  1998/09/09 07:32:12  src
 *  Version 1.1
 *
 *  Revision 1.5  1998/07/12 09:39:29  src
 *  newsx version 1.0
 */

/*
 *  length of a news header line
 *  not to be confused with NNTP_STRLEN
 */
#define MAX_HEADER_SIZE 5120

/* 
 *  lock between newsxes accessing same host
 *  name compatible with INN innstat
 */
#define LOCK_PREFIX     "LOCK.newsx."

/* 
 *  lock between newsxes accessing same log file
 */
#define LOCK_SUFFIX     ".LOCKnewsx"

/* 
 *  outgoing  
 */
#define C_TOGO          "togo"          /* C News */
#define C_LOCK          "LOCKb"         /* C News */
#define I_LOCK          "LOCK."         /* INN */

#define C_SYS_FILE      "sys"           /* C News */

/* 
 *  incoming
 */
#define _INTMP          ".tmp."         /* temp prefix, invisible to newsrun */
#define _C_SPOOL        "%ld.%d.%d.t"   /* C incoming news name, uncompressed */
#define TEMP_PATTERN    "XXXXXX"        /* for temporary files, see newstemp() */

/*
 *  control
 */
#define INN_CTL         "ctlinnd"       /* INN */
#define INN_CTL_FLUSH   "flush"         /* INN ctlinnd */

/*
 *  "magic" newsx path tag
 */
#define NEWSX_PATH      "newsx"

/*
 *  newsx standard configuration file
 */
#define NEWSX_CONF      "newsx.conf"

/* 
 *  general
 */
#define _RETRY          ".retry"
#define _OLD            ".old"
#define _TMP            ".tmp"
#define _TOGO           ".togo"
#define _CONF           ".conf"
